summaryrefslogtreecommitdiffstats
path: root/src/loggerengine.h
diff options
context:
space:
mode:
authorJonathan Bauer2011-04-24 16:59:50 +0200
committerJonathan Bauer2011-04-24 16:59:50 +0200
commit51a1b87480973792fcadb35767d7b61f32d12df9 (patch)
tree401e398cd7627f1578179cea7582c98f361b8941 /src/loggerengine.h
parentdm thread ending properly now, few fixes (diff)
downloadfbgui-51a1b87480973792fcadb35767d7b61f32d12df9.tar.gz
fbgui-51a1b87480973792fcadb35767d7b61f32d12df9.tar.xz
fbgui-51a1b87480973792fcadb35767d7b61f32d12df9.zip
auto-close removed, handled by fbgui nowmake
Diffstat (limited to 'src/loggerengine.h')
-rw-r--r--src/loggerengine.h13
1 files changed, 12 insertions, 1 deletions
diff --git a/src/loggerengine.h b/src/loggerengine.h
index 95a8f93..45f6827 100644
--- a/src/loggerengine.h
+++ b/src/loggerengine.h
@@ -49,9 +49,20 @@ public:
LoggerEngine_std();
~LoggerEngine_std();
// reimplemented virtual functions of QxtBasicSTDLoggerEngineqqq
void writeToStdOut(const QString& level, const QList<QVariant> &msgs);
void writeToStdErr(const QString& str_level, const QList<QVariant> &msgs);
};
+//---------------------------------------------------------------------------------------------------
+// slighty modified QxtBasicFileLoggerEngine
+//---------------------------------------------------------------------------------------------------
+class LoggerEngine_file: public QxtBasicFileLoggerEngine {
+public:
+ LoggerEngine_file();
+ ~LoggerEngine_file();
+
+ // reimplemented virtual functions of QxtBasicFileLoggerEngine
+ void writeToFile(const QString& level, const QList<QVariant> &msgs);
+};
#endif // LOGGERENGINE_H_
@@ -49,9 +49,20 @@ public:
LoggerEngine_std();
~LoggerEngine_std();
- // reimplemented virtual functions of QxtBasicSTDLoggerEngineqqq
+ // reimplemented virtual functions of QxtBasicSTDLoggerEngine
void writeToStdOut(const QString& level, const QList<QVariant> &msgs);
void writeToStdErr(const QString& str_level, const QList<QVariant> &msgs);